@@ -41,6 +41,7 @@ use super::documents::LanguageId;
 use super::lsp_custom;
 use super::parent_process_checker;
 use super::performance::Performance;
+use super::refactor;
 use super::registries;
 use super::sources;
 use super::sources::Sources;
@@ -95,6 +96,9 @@ pub(crate) struct Inner {
   module_registries: registries::ModuleRegistry,
   /// The path to the module registries cache
   module_registries_location: PathBuf,
+  /// An optional path to the DENO_DIR which has been specified in the client
+  /// options.
+  maybe_cache_path: Option<PathBuf>,
   /// An optional configuration file which has been specified in the client
   /// options.
   maybe_config_file: Option<ConfigFile>,
@@ -144,10 +148,11 @@ impl Inner {
       config,
       diagnostics_server,
       documents: Default::default(),
-      maybe_config_file: Default::default(),
-      maybe_config_uri: Default::default(),
-      maybe_import_map: Default::default(),
-      maybe_import_map_uri: Default::default(),
+      maybe_cache_path: None,
+      maybe_config_file: None,
+      maybe_config_uri: None,
+      maybe_import_map: None,
+      maybe_import_map_uri: None,
       module_registries,
       module_registries_location,
       performance,
@@ -358,7 +363,7 @@ impl Inner {
     self.maybe_config_uri = None;
     if let Some(config_str) = maybe_config {
       if !config_str.is_empty() {
-        info!("Updating TypeScript configuration from: \"{}\"", config_str);
+        info!("Setting TypeScript configuration from: \"{}\"", config_str);
         let config_url = if let Ok(url) = Url::from_file_path(config_str) {
           Ok(url)
         } else if let Some(root_uri) = maybe_root_uri {
@@ -417,6 +422,62 @@ impl Inner {
     })
   }
 
+  pub fn update_cache(&mut self) -> Result<(), AnyError> {
+    let mark = self.performance.mark("update_cache", None::<()>);
+    self.performance.measure(mark);
+    let (maybe_cache, maybe_root_uri) = {
+      let config = &self.config;
+      (
+        config.get_workspace_settings().cache,
+        config.root_uri.clone(),
+      )
+    };
+    let maybe_cache_path = if let Some(cache_str) = &maybe_cache {
+      info!("Setting cache path from: \"{}\"", cache_str);
+      let cache_url = if let Ok(url) = Url::from_file_path(cache_str) {
+        Ok(url)
+      } else if let Some(root_uri) = &maybe_root_uri {
+        let root_path = root_uri
+          .to_file_path()
+          .map_err(|_| anyhow!("Bad root_uri: {}", root_uri))?;
+        let cache_path = root_path.join(cache_str);
+        Url::from_file_path(cache_path).map_err(|_| {
+          anyhow!("Bad file path for import path: {:?}", cache_str)
+        })
+      } else {
+        Err(anyhow!(
+          "The path to the cache path (\"{}\") is not resolvable.",
+          cache_str
+        ))
+      }?;
+      let cache_path = cache_url.to_file_path().map_err(|_| {
+        anyhow!("Cannot convert \"{}\" into a file path.", cache_url)
+      })?;
+      info!(
+        "  Resolved cache path: \"{}\"",
+        cache_path.to_string_lossy()
+      );
+      Some(cache_path)
+    } else {
+      None
+    };
+    if self.maybe_cache_path != maybe_cache_path {
+      let maybe_custom_root = maybe_cache_path
+        .clone()
+        .or_else(|| env::var("DENO_DIR").map(String::into).ok());
+      let dir = deno_dir::DenoDir::new(maybe_custom_root)
+        .expect("could not access DENO_DIR");
+      let module_registries_location = dir.root.join(REGISTRIES_PATH);
+      self.module_registries =
+        registries::ModuleRegistry::new(&module_registries_location);
+      self.module_registries_location = module_registries_location;
+      let sources_location = dir.root.join(SOURCES_PATH);
+      self.sources = Sources::new(&sources_location);
+      self.maybe_cache_path = maybe_cache_path;
+    }
+    Ok(())
+  }
+
   pub async fn update_import_map(&mut self) -> Result<(), AnyError> {
     let mark = self.performance.mark("update_import_map", None::<()>);
     let (maybe_import_map, maybe_root_uri) = {
@@ -427,7 +488,7 @@ impl Inner {
       )
     };
     if let Some(import_map_str) = &maybe_import_map {
-      info!("Updating import map from: \"{}\"", import_map_str);
+      info!("Setting import map from: \"{}\"", import_map_str);
       let import_map_url = if let Ok(url) = Url::from_file_path(import_map_str)
       {
         Ok(url)
@@ -560,7 +621,7 @@ impl Inner {
       Ok(maybe_asset.clone())
     } else {
       let maybe_asset =
-        tsc::get_asset(&specifier, &self.ts_server, self.snapshot()?).await?;
+        tsc::get_asset(specifier, &self.ts_server, self.snapshot()?).await?;
       self.assets.insert(specifier.clone(), maybe_asset.clone());
       Ok(maybe_asset)
     }
@@ -620,8 +681,12 @@ impl Inner {
     }
 
     self.update_debug_flag();
+    // Check to see if we need to change the cache path
+    if let Err(err) = self.update_cache() {
+      self.client.show_message(MessageType::Warning, err).await;
+    }
     if let Err(err) = self.update_tsconfig().await {
-      warn!("Updating tsconfig has errored: {}", err);
+      self.client.show_message(MessageType::Warning, err).await;
     }
 
     if capabilities.code_action_provider.is_some() {
@@ -636,14 +701,6 @@ impl Inner {
       self.ts_fixable_diagnostics = fixable_diagnostics;
     }
 
-    self.performance.measure(mark);
-    Ok(InitializeResult {
-      capabilities,
-      server_info: Some(server_info),
-    })
-  }
-
-  async fn initialized(&mut self, _: InitializedParams) {
     // Check to see if we need to setup the import map
     if let Err(err) = self.update_import_map().await {
       self.client.show_message(MessageType::Warning, err).await;
@@ -653,6 +710,14 @@ impl Inner {
       self.client.show_message(MessageType::Warning, err).await;
     }
 
+    self.performance.measure(mark);
+    Ok(InitializeResult {
+      capabilities,
+      server_info: Some(server_info),
+    })
+  }
+
+  async fn initialized(&mut self, _: InitializedParams) {
     if self
       .config
       .client_capabilities
@@ -707,13 +772,21 @@ impl Inner {
       // already managed by the language service
       return;
     }
-    let language_id = match params.text_document.language_id.parse() {
-      Ok(language_id) => language_id,
-      Err(err) => {
-        error!("{}", err);
-        LanguageId::TypeScript
-      }
-    };
+    let language_id =
+      params
+        .text_document
+        .language_id
+        .parse()
+        .unwrap_or_else(|err| {
+          error!("{}", err);
+          LanguageId::Unknown
+        });
+    if language_id == LanguageId::Unknown {
+      warn!(
+        "Unsupported language id \"{}\" received for document \"{}\".",
+        params.text_document.language_id, params.text_document.uri
+      );
+    }
     let media_type = MediaType::from(&language_id);
     self.documents.open(
       specifier.clone(),
@@ -771,15 +844,21 @@ impl Inner {
   async fn did_close(&mut self, params: DidCloseTextDocumentParams) {
     let mark = self.performance.mark("did_close", Some(&params));
     if params.text_document.uri.scheme() == "deno" {
-      // we can ignore virtual text documents opening, as they don't need to
+      // we can ignore virtual text documents closing, as they don't need to
       // be tracked in memory, as they are static assets that won't change
       // already managed by the language service
       return;
     }
     let specifier = self.url_map.normalize_url(&params.text_document.uri);
-    self.documents.close(&specifier);
+    let is_diagnosable = self.documents.is_diagnosable(&specifier);
 
-    if self.documents.is_diagnosable(&specifier) {
+    if is_diagnosable {
+      let mut specifiers = self.documents.dependents(&specifier);
+      specifiers.push(specifier.clone());
+      self.diagnostics_server.invalidate(specifiers).await;
+    }
+    self.documents.close(&specifier);
+    if is_diagnosable {
       if let Err(err) = self.diagnostics_server.update() {
         error!("{}", err);
       }
@@ -830,6 +909,9 @@ impl Inner {
     }
 
     self.update_debug_flag();
+    if let Err(err) = self.update_cache() {
+      self.client.show_message(MessageType::Warning, err).await;
+    }
     if let Err(err) = self.update_import_map().await {
       self.client.show_message(MessageType::Warning, err).await;
     }
@@ -1083,6 +1165,10 @@ impl Inner {
     }
 
     let mark = self.performance.mark("code_action", Some(&params));
+    let mut all_actions = CodeActionResponse::new();
+    let line_index = self.get_line_index_sync(&specifier).unwrap();
+
+    // QuickFix
     let fixable_diagnostics: Vec<&Diagnostic> = params
       .context
       .diagnostics
@@ -1110,93 +1196,146 @@ impl Inner {
         None => false,
       })
       .collect();
-    if fixable_diagnostics.is_empty() {
-      self.performance.measure(mark);
-      return Ok(None);
-    }
-    let line_index = self.get_line_index_sync(&specifier).unwrap();
-    let mut code_actions = CodeActionCollection::default();
-    let file_diagnostics = self
-      .diagnostics_server
-      .get(&specifier, DiagnosticSource::TypeScript)
-      .await;
-    for diagnostic in &fixable_diagnostics {
-      match diagnostic.source.as_deref() {
-        Some("deno-ts") => {
-          let code = match diagnostic.code.as_ref().unwrap() {
-            NumberOrString::String(code) => code.to_string(),
-            NumberOrString::Number(code) => code.to_string(),
-          };
-          let codes = vec![code];
-          let req = tsc::RequestMethod::GetCodeFixes((
-            specifier.clone(),
-            line_index.offset_tsc(diagnostic.range.start)?,
-            line_index.offset_tsc(diagnostic.range.end)?,
-            codes,
-          ));
-          let actions: Vec<tsc::CodeFixAction> =
-            match self.ts_server.request(self.snapshot()?, req).await {
-              Ok(items) => items,
-              Err(err) => {
-                // sometimes tsc reports errors when retrieving code actions
-                // because they don't reflect the current state of the document
-                // so we will log them to the output, but we won't send an error
-                // message back to the client.
-                error!("Error getting actions from TypeScript: {}", err);
-                Vec::new()
-              }
+    if !fixable_diagnostics.is_empty() {
+      let mut code_actions = CodeActionCollection::default();
+      let file_diagnostics = self
+        .diagnostics_server
+        .get(&specifier, DiagnosticSource::TypeScript)
+        .await;
+      for diagnostic in &fixable_diagnostics {
+        match diagnostic.source.as_deref() {
+          Some("deno-ts") => {
+            let code = match diagnostic.code.as_ref().unwrap() {
+              NumberOrString::String(code) => code.to_string(),
+              NumberOrString::Number(code) => code.to_string(),
             };
-          for action in actions {
-            code_actions
-              .add_ts_fix_action(&specifier, &action, diagnostic, self)
-              .await
-              .map_err(|err| {
-                error!("Unable to convert fix: {}", err);
-                LspError::internal_error()
-              })?;
-            if code_actions.is_fix_all_action(
-              &action,
-              diagnostic,
-              &file_diagnostics,
-            ) {
+            let codes = vec![code];
+            let req = tsc::RequestMethod::GetCodeFixes((
+              specifier.clone(),
+              line_index.offset_tsc(diagnostic.range.start)?,
+              line_index.offset_tsc(diagnostic.range.end)?,
+              codes,
+            ));
+            let actions: Vec<tsc::CodeFixAction> =
+              match self.ts_server.request(self.snapshot()?, req).await {
+                Ok(items) => items,
+                Err(err) => {
+                  // sometimes tsc reports errors when retrieving code actions
+                  // because they don't reflect the current state of the document
+                  // so we will log them to the output, but we won't send an error
+                  // message back to the client.
+                  error!("Error getting actions from TypeScript: {}", err);
+                  Vec::new()
+                }
+              };
+            for action in actions {
               code_actions
-                .add_ts_fix_all_action(&action, &specifier, diagnostic);
+                .add_ts_fix_action(&specifier, &action, diagnostic, self)
+                .await
+                .map_err(|err| {
+                  error!("Unable to convert fix: {}", err);
+                  LspError::internal_error()
+                })?;
+              if code_actions.is_fix_all_action(
+                &action,
+                diagnostic,
+                &file_diagnostics,
+              ) {
+                code_actions
+                  .add_ts_fix_all_action(&action, &specifier, diagnostic);
+              }
             }
           }
-        }
-        Some("deno") => {
-          code_actions
+          Some("deno") => code_actions
             .add_deno_fix_action(diagnostic)
             .map_err(|err| {
               error!("{}", err);
               LspError::internal_error()
-            })?
+            })?,
+          Some("deno-lint") => code_actions
+            .add_deno_lint_ignore_action(
+              &specifier,
+              self.documents.docs.get(&specifier),
+              diagnostic,
+            )
+            .map_err(|err| {
+              error!("Unable to fix lint error: {}", err);
+              LspError::internal_error()
+            })?,
+          _ => (),
         }
-        Some("deno-lint") => code_actions
-          .add_deno_lint_ignore_action(
-            &specifier,
-            self.documents.docs.get(&specifier),
-            diagnostic,
-          )
-          .map_err(|err| {
-            error!("Unable to fix lint error: {}", err);
-            LspError::internal_error()
-          })?,
-        _ => (),
       }
+      code_actions.set_preferred_fixes();
+      all_actions.extend(code_actions.get_response());
     }
-    code_actions.set_preferred_fixes();
-    let code_action_response = code_actions.get_response();
+
+    // Refactor
+    let start = line_index.offset_tsc(params.range.start)?;
+    let length = line_index.offset_tsc(params.range.end)? - start;
+    let only =
+      params
+        .context
+        .only
+        .as_ref()
+        .map_or(String::default(), |values| {
+          values
+            .first()
+            .map_or(String::default(), |v| v.as_str().to_owned())
+        });
+    let req = tsc::RequestMethod::GetApplicableRefactors((
+      specifier.clone(),
+      tsc::TextSpan { start, length },
+      only,
+    ));
+    let refactor_infos: Vec<tsc::ApplicableRefactorInfo> = self
+      .ts_server
+      .request(self.snapshot()?, req)
+      .await
+      .map_err(|err| {
+        error!("Failed to request to tsserver {}", err);
+        LspError::invalid_request()
+      })?;
+    let mut refactor_actions = Vec::<CodeAction>::new();
+    for refactor_info in refactor_infos.iter() {
+      refactor_actions
+        .extend(refactor_info.to_code_actions(&specifier, &params.range));
+    }
+    all_actions.extend(
+      refactor::prune_invalid_actions(&refactor_actions, 5)
+        .into_iter()
+        .map(CodeActionOrCommand::CodeAction),
+    );
+
+    let code_action_disabled_support =
+      self.config.client_capabilities.code_action_disabled_support;
+    let actions: Vec<CodeActionOrCommand> = all_actions.into_iter().filter(|ca| {
+      code_action_disabled_support
+        || matches!(ca, CodeActionOrCommand::CodeAction(ca) if ca.disabled.is_none())
+    }).collect();
+    let response = if actions.is_empty() {
+      None
+    } else {
+      Some(actions)
+    };
+
     self.performance.measure(mark);
-    Ok(Some(code_action_response))
+    Ok(response)
   }
 
   async fn code_action_resolve(
     &mut self,
     params: CodeAction,
   ) -> LspResult<CodeAction> {
+    if params.kind.is_none() || params.data.is_none() {
+      return Ok(params);
+    }
+
     let mark = self.performance.mark("code_action_resolve", Some(&params));
-    let result = if let Some(data) = params.data.clone() {
+    let kind = params.kind.clone().unwrap();
+    let data = params.data.clone().unwrap();
+
+    let result = if kind.as_str().starts_with(CodeActionKind::QUICKFIX.as_str())
+    {
       let code_action_data: CodeActionData =
         from_value(data).map_err(|err| {
           error!("Unable to decode code action data: {}", err);
@@ -1216,35 +1355,69 @@ impl Inner {
         })?;
       if combined_code_actions.commands.is_some() {
         error!("Deno does not support code actions with commands.");
-        Err(LspError::invalid_request())
-      } else {
-        let changes = if code_action_data.fix_id == "fixMissingImport" {
-          fix_ts_import_changes(
-            &code_action_data.specifier,
-            &combined_code_actions.changes,
-            self,
-          )
-          .map_err(|err| {
-            error!("Unable to remap changes: {}", err);
-            LspError::internal_error()
-          })?
-        } else {
-          combined_code_actions.changes.clone()
-        };
-        let mut code_action = params.clone();
-        code_action.edit =
-          ts_changes_to_edit(&changes, self).await.map_err(|err| {
-            error!("Unable to convert changes to edits: {}", err);
-            LspError::internal_error()
-          })?;
-        Ok(code_action)
+        return Err(LspError::invalid_request());
       }
+
+      let changes = if code_action_data.fix_id == "fixMissingImport" {
+        fix_ts_import_changes(
+          &code_action_data.specifier,
+          &combined_code_actions.changes,
+          self,
+        )
+        .map_err(|err| {
+          error!("Unable to remap changes: {}", err);
+          LspError::internal_error()
+        })?
+      } else {
+        combined_code_actions.changes.clone()
+      };
+      let mut code_action = params.clone();
+      code_action.edit =
+        ts_changes_to_edit(&changes, self).await.map_err(|err| {
+          error!("Unable to convert changes to edits: {}", err);
+          LspError::internal_error()
+        })?;
+      code_action
+    } else if kind.as_str().starts_with(CodeActionKind::REFACTOR.as_str()) {
+      let mut code_action = params.clone();
+      let action_data: refactor::RefactorCodeActionData = from_value(data)
+        .map_err(|err| {
+          error!("Unable to decode code action data: {}", err);
+          LspError::invalid_params("The CodeAction's data is invalid.")
+        })?;
+      let line_index =
+        self.get_line_index_sync(&action_data.specifier).unwrap();
+      let start = line_index.offset_tsc(action_data.range.start)?;
+      let length = line_index.offset_tsc(action_data.range.end)? - start;
+      let req = tsc::RequestMethod::GetEditsForRefactor((
+        action_data.specifier.clone(),
+        tsc::TextSpan { start, length },
+        action_data.refactor_name.clone(),
+        action_data.action_name.clone(),
+      ));
+      let refactor_edit_info: tsc::RefactorEditInfo = self
+        .ts_server
+        .request(self.snapshot()?, req)
+        .await
+        .map_err(|err| {
+          error!("Failed to request to tsserver {}", err);
+          LspError::invalid_request()
+        })?;
+      code_action.edit = refactor_edit_info
+        .to_workspace_edit(self)
+        .await
+        .map_err(|err| {
+          error!("Unable to convert changes to edits: {}", err);
+          LspError::internal_error()
+        })?;
+      code_action
     } else {
       // The code action doesn't need to be resolved
-      Ok(params)
+      params
     };
+
     self.performance.measure(mark);
-    result
+    Ok(result)
   }
 
   async fn code_lens(
@@ -2407,6 +2580,7 @@ impl Inner {
           &specifier,
           &self.maybe_import_map,
           &self.maybe_config_file,
+          &self.maybe_cache_path,
         )
         .await
         .map_err(|err| {
@@ -2419,6 +2593,7 @@ impl Inner {
         &referrer,
         &self.maybe_import_map,
         &self.maybe_config_file,
+        &self.maybe_cache_path,
       )
       .await
       .map_err(|err| {
