@@ -61,6 +61,7 @@ use deno_core::resolve_url_or_path;
 use deno_core::serde_json;
 use deno_core::serde_json::json;
 use deno_core::v8_set_flags;
+use deno_core::JsRuntime;
 use deno_core::ModuleSpecifier;
 use deno_runtime::ops::worker_host::CreateWebWorkerCb;
 use deno_runtime::permissions::Permissions;
@@ -75,6 +76,7 @@ use std::env;
 use std::io::Read;
 use std::io::Write;
 use std::iter::once;
+use std::num::NonZeroUsize;
 use std::path::PathBuf;
 use std::pin::Pin;
 use std::rc::Rc;
@@ -109,13 +111,19 @@ fn create_web_worker_callback(
         .log_level
         .map_or(false, |l| l == log::Level::Debug),
       unstable: program_state.flags.unstable,
-      ca_data: program_state.ca_data.clone(),
+      enable_testing_features: program_state.flags.enable_testing_features,
+      unsafely_ignore_certificate_errors: program_state
+        .flags
+        .unsafely_ignore_certificate_errors
+        .clone(),
+      root_cert_store: program_state.root_cert_store.clone(),
       user_agent: version::get_user_agent(),
       seed: program_state.flags.seed,
       module_loader,
       create_web_worker_cb,
       js_error_create_fn: Some(js_error_create_fn),
       use_deno_namespace: args.use_deno_namespace,
+      worker_type: args.worker_type,
       maybe_inspector_server,
       runtime_version: version::deno(),
       ts_version: version::TYPESCRIPT.to_string(),
@@ -126,6 +134,7 @@ fn create_web_worker_callback(
       shared_array_buffer_store: Some(
         program_state.shared_array_buffer_store.clone(),
       ),
+      cpu_count: num_cpus::get(),
     };
 
     let (mut worker, external_handle) = WebWorker::from_options(
@@ -162,7 +171,7 @@ pub fn create_main_worker(
   program_state: &Arc<ProgramState>,
   main_module: ModuleSpecifier,
   permissions: Permissions,
-  enable_testing: bool,
+  maybe_op_init: Option<&dyn Fn(&mut JsRuntime)>,
 ) -> MainWorker {
   let module_loader = CliModuleLoader::new(program_state.clone());
 
@@ -188,7 +197,12 @@ pub fn create_main_worker(
       .log_level
       .map_or(false, |l| l == log::Level::Debug),
     unstable: program_state.flags.unstable,
-    ca_data: program_state.ca_data.clone(),
+    enable_testing_features: program_state.flags.enable_testing_features,
+    unsafely_ignore_certificate_errors: program_state
+      .flags
+      .unsafely_ignore_certificate_errors
+      .clone(),
+    root_cert_store: program_state.root_cert_store.clone(),
     user_agent: version::get_user_agent(),
     seed: program_state.flags.seed,
     js_error_create_fn: Some(js_error_create_fn),
@@ -215,6 +229,7 @@ pub fn create_main_worker(
     shared_array_buffer_store: Some(
       program_state.shared_array_buffer_store.clone(),
     ),
+    cpu_count: num_cpus::get(),
   };
 
   let mut worker = MainWorker::from_options(main_module, permissions, &options);
@@ -232,8 +247,8 @@ pub fn create_main_worker(
     ops::errors::init(js_runtime);
     ops::runtime_compiler::init(js_runtime);
 
-    if enable_testing {
-      ops::testing::init(js_runtime);
+    if let Some(op_init) = maybe_op_init {
+      op_init(js_runtime);
     }
 
     js_runtime.sync_ops_cache();
@@ -470,7 +485,7 @@ async fn install_command(
   let program_state = ProgramState::build(preload_flags).await?;
   let main_module = resolve_url_or_path(&module_url)?;
   let mut worker =
-    create_main_worker(&program_state, main_module.clone(), permissions, false);
+    create_main_worker(&program_state, main_module.clone(), permissions, None);
   // First, fetch and compile the module; this step ensures that the module exists.
   worker.preload_module(&main_module).await?;
   tools::installer::install(flags, &module_url, args, name, root, force)
@@ -534,7 +549,7 @@ async fn eval_command(
   let permissions = Permissions::from_options(&flags.clone().into());
   let program_state = ProgramState::build(flags).await?;
   let mut worker =
-    create_main_worker(&program_state, main_module.clone(), permissions, false);
+    create_main_worker(&program_state, main_module.clone(), permissions, None);
   // Create a dummy source file.
   let source_code = if print {
     format!("console.log({})", code)
@@ -772,15 +787,18 @@ async fn format_command(
   Ok(())
 }
 
-async fn run_repl(flags: Flags) -> Result<(), AnyError> {
+async fn run_repl(
+  flags: Flags,
+  maybe_eval: Option<String>,
+) -> Result<(), AnyError> {
   let main_module = resolve_url_or_path("./$deno$repl.ts").unwrap();
   let permissions = Permissions::from_options(&flags.clone().into());
   let program_state = ProgramState::build(flags).await?;
   let mut worker =
-    create_main_worker(&program_state, main_module.clone(), permissions, false);
+    create_main_worker(&program_state, main_module.clone(), permissions, None);
   worker.run_event_loop(false).await?;
 
-  tools::repl::run(&program_state, worker).await
+  tools::repl::run(&program_state, worker, maybe_eval).await
 }
 
 async fn run_from_stdin(flags: Flags) -> Result<(), AnyError> {
@@ -791,7 +809,7 @@ async fn run_from_stdin(flags: Flags) -> Result<(), AnyError> {
     &program_state.clone(),
     main_module.clone(),
     permissions,
-    false,
+    None,
   );
 
   let mut source = Vec::new();
@@ -884,7 +902,7 @@ async fn run_with_watch(flags: Flags, script: String) -> Result<(), AnyError> {
           &program_state,
           main_module.clone(),
           permissions,
-          false,
+          None,
         );
         debug!("main_module {}", main_module);
         worker.execute_module(&main_module).await?;
@@ -918,7 +936,7 @@ async fn run_command(flags: Flags, script: String) -> Result<(), AnyError> {
   let program_state = ProgramState::build(flags.clone()).await?;
   let permissions = Permissions::from_options(&flags.clone().into());
   let mut worker =
-    create_main_worker(&program_state, main_module.clone(), permissions, false);
+    create_main_worker(&program_state, main_module.clone(), permissions, None);
 
   let mut maybe_coverage_collector =
     if let Some(ref coverage_dir) = program_state.coverage_dir {
@@ -986,12 +1004,11 @@ async fn test_command(
   include: Option<Vec<String>>,
   no_run: bool,
   doc: bool,
-  fail_fast: Option<usize>,
-  quiet: bool,
+  fail_fast: Option<NonZeroUsize>,
   allow_none: bool,
   filter: Option<String>,
   shuffle: Option<u64>,
-  concurrent_jobs: usize,
+  concurrent_jobs: NonZeroUsize,
 ) -> Result<(), AnyError> {
   if let Some(ref coverage_dir) = flags.coverage_dir {
     std::fs::create_dir_all(&coverage_dir)?;
@@ -1006,7 +1023,6 @@ async fn test_command(
   let program_state = ProgramState::build(flags.clone()).await?;
 
   let include = include.unwrap_or_else(|| vec![".".to_string()]);
-  let cwd = std::env::current_dir().expect("No current directory");
 
   let permissions = Permissions::from_options(&flags.clone().into());
   let lib = if flags.unstable {
@@ -1027,16 +1043,14 @@ async fn test_command(
     // TODO(caspervonb) clean this up.
     let resolver = |changed: Option<Vec<PathBuf>>| {
       let test_modules_result = if doc {
-        test_runner::collect_test_module_specifiers(
+        fs_util::collect_specifiers(
           include.clone(),
-          &cwd,
-          fs_util::is_supported_ext,
+          fs_util::is_supported_test_ext,
         )
       } else {
-        test_runner::collect_test_module_specifiers(
+        fs_util::collect_specifiers(
           include.clone(),
-          &cwd,
-          tools::test_runner::is_supported,
+          fs_util::is_supported_test_path,
         )
       };
 
@@ -1086,7 +1100,7 @@ async fn test_command(
                   output.insert(specifier);
 
                   get_dependencies(
-                    &graph,
+                    graph,
                     graph.get_specifier(specifier)?,
                     output,
                   )?;
@@ -1097,7 +1111,7 @@ async fn test_command(
                   output.insert(specifier);
 
                   get_dependencies(
-                    &graph,
+                    graph,
                     graph.get_specifier(specifier)?,
                     output,
                   )?;
@@ -1160,7 +1174,6 @@ async fn test_command(
     };
 
     let operation = |modules_to_reload: Vec<ModuleSpecifier>| {
-      let cwd = cwd.clone();
       let filter = filter.clone();
       let include = include.clone();
       let lib = lib.clone();
@@ -1169,10 +1182,9 @@ async fn test_command(
 
       async move {
         let doc_modules = if doc {
-          test_runner::collect_test_module_specifiers(
+          fs_util::collect_specifiers(
             include.clone(),
-            &cwd,
-            fs_util::is_supported_ext,
+            fs_util::is_supported_test_ext,
           )?
         } else {
           Vec::new()
@@ -1184,10 +1196,9 @@ async fn test_command(
           .cloned()
           .collect();
 
-        let test_modules = test_runner::collect_test_module_specifiers(
+        let test_modules = fs_util::collect_specifiers(
           include.clone(),
-          &cwd,
-          tools::test_runner::is_supported,
+          fs_util::is_supported_test_path,
         )?;
 
         let test_modules_to_reload = test_modules
@@ -1204,7 +1215,6 @@ async fn test_command(
           test_modules_to_reload,
           no_run,
           fail_fast,
-          quiet,
           true,
           filter.clone(),
           shuffle,
@@ -1219,19 +1229,17 @@ async fn test_command(
     file_watcher::watch_func(resolver, operation, "Test").await?;
   } else {
     let doc_modules = if doc {
-      test_runner::collect_test_module_specifiers(
+      fs_util::collect_specifiers(
         include.clone(),
-        &cwd,
-        fs_util::is_supported_ext,
+        fs_util::is_supported_test_ext,
       )?
     } else {
       Vec::new()
     };
 
-    let test_modules = test_runner::collect_test_module_specifiers(
+    let test_modules = fs_util::collect_specifiers(
       include.clone(),
-      &cwd,
-      tools::test_runner::is_supported,
+      fs_util::is_supported_test_path,
     )?;
 
     test_runner::run_tests(
@@ -1242,7 +1250,6 @@ async fn test_command(
       test_modules,
       no_run,
       fail_fast,
-      quiet,
       allow_none,
       filter,
       shuffle,
@@ -1339,13 +1346,12 @@ fn get_subcommand(
       ignore,
       json,
     } => lint_command(flags, files, rules, ignore, json).boxed_local(),
-    DenoSubcommand::Repl => run_repl(flags).boxed_local(),
+    DenoSubcommand::Repl { eval } => run_repl(flags, eval).boxed_local(),
     DenoSubcommand::Run { script } => run_command(flags, script).boxed_local(),
     DenoSubcommand::Test {
       no_run,
       doc,
       fail_fast,
-      quiet,
       include,
       allow_none,
       filter,
@@ -1357,7 +1363,6 @@ fn get_subcommand(
       no_run,
       doc,
       fail_fast,
-      quiet,
       allow_none,
       filter,
       shuffle,
