@@ -12,17 +12,17 @@ use tempfile::TempDir;
 use test_util::deno_exe_path;
 use test_util::http_server;
 use test_util::lsp::LspClient;
-use test_util::root_path;
+use test_util::testdata_path;
 
 fn load_fixture(path: &str) -> Value {
-  let fixtures_path = root_path().join("cli/tests/lsp");
+  let fixtures_path = testdata_path().join("lsp");
   let path = fixtures_path.join(path);
   let fixture_str = fs::read_to_string(path).unwrap();
   serde_json::from_str(&fixture_str).unwrap()
 }
 
 fn load_fixture_str(path: &str) -> String {
-  let fixtures_path = root_path().join("cli/tests/lsp");
+  let fixtures_path = testdata_path().join("lsp");
   let path = fixtures_path.join(path);
   fs::read_to_string(path).unwrap()
 }
@@ -502,7 +502,7 @@ fn lsp_hover_unstable_disabled() {
         "uri": "file:///a/file.ts",
         "languageId": "typescript",
         "version": 1,
-        "text": "console.log(Deno.openPlugin);\n"
+        "text": "console.log(Deno.dlopen);\n"
       }
     }),
   );
@@ -537,7 +537,7 @@ fn lsp_hover_unstable_disabled() {
         },
         "end": {
           "line": 0,
-          "character": 27
+          "character": 23
         }
       }
     }))
@@ -555,7 +555,7 @@ fn lsp_hover_unstable_enabled() {
         "uri": "file:///a/file.ts",
         "languageId": "typescript",
         "version": 1,
-        "text": "console.log(Deno.openPlugin);\n"
+        "text": "console.log(Deno.ppid);\n"
       }
     }),
   );
@@ -580,9 +580,9 @@ fn lsp_hover_unstable_enabled() {
       "contents":[
         {
           "language":"typescript",
-          "value":"function Deno.openPlugin(filename: string): number"
+          "value":"const Deno.ppid: number"
         },
-        "**UNSTABLE**: new API, yet to be vetted.\n\nOpen and initialize a plugin.\n\n```ts\nimport { assert } from \"https://deno.land/std/testing/asserts.ts\";\nconst rid = Deno.openPlugin(\"./path/to/some/plugin.so\");\n\n// The Deno.core namespace is needed to interact with plugins, but this is\n// internal so we use ts-ignore to skip type checking these calls.\n// @ts-ignore\nconst { op_test_sync, op_test_async } = Deno.core.ops();\n\nassert(op_test_sync);\nassert(op_test_async);\n\n// @ts-ignore\nconst result = Deno.core.opSync(\"op_test_sync\");\n\n// @ts-ignore\nconst result = await Deno.core.opAsync(\"op_test_sync\");\n```\n\nRequires `allow-plugin` permission.\n\nThe plugin system is not stable and will change in the future, hence the\nlack of docs. For now take a look at the example\nhttps://github.com/denoland/deno/tree/main/test_plugin"
+        "The pid of the current process's parent."
       ],
       "range":{
         "start":{
@@ -591,7 +591,7 @@ fn lsp_hover_unstable_enabled() {
         },
         "end":{
           "line":0,
-          "character":27
+          "character":21
         }
       }
     }))
@@ -921,7 +921,7 @@ fn lsp_hover_dependency() {
     Some(json!({
       "contents": {
         "kind": "markdown",
-        "value": "**Resolved Dependency**\n\n**Code**: http&#8203;://127.0.0.1:4545/cli/tests/subdir/type_reference.js\n"
+        "value": "**Resolved Dependency**\n\n**Code**: http&#8203;://127.0.0.1:4545/subdir/type_reference.js\n"
       },
       "range": {
         "start": {
@@ -930,7 +930,7 @@ fn lsp_hover_dependency() {
         },
         "end":{
           "line": 3,
-          "character": 76
+          "character": 66
         }
       }
     }))
@@ -955,7 +955,7 @@ fn lsp_hover_dependency() {
     Some(json!({
       "contents": {
         "kind": "markdown",
-        "value": "**Resolved Dependency**\n\n**Code**: http&#8203;://127.0.0.1:4545/cli/tests/subdir/mod1.ts\n"
+        "value": "**Resolved Dependency**\n\n**Code**: http&#8203;://127.0.0.1:4545/subdir/mod1.ts\n"
       },
       "range": {
         "start": {
@@ -964,7 +964,7 @@ fn lsp_hover_dependency() {
         },
         "end":{
           "line": 4,
-          "character": 66
+          "character": 56
         }
       }
     }))
@@ -2115,6 +2115,93 @@ fn lsp_code_actions_imports() {
   shutdown(&mut client);
 }
 
+#[test]
+fn lsp_code_actions_refactor() {
+  let mut client = init("initialize_params.json");
+  did_open(
+    &mut client,
+    json!({
+      "textDocument": {
+        "uri": "file:///a/file.ts",
+        "languageId": "typescript",
+        "version": 1,
+        "text": "var x: { a?: number; b?: string } = {};\n"
+      }
+    }),
+  );
+  let (maybe_res, maybe_err) = client
+    .write_request(
+      "textDocument/codeAction",
+      load_fixture("code_action_params_refactor.json"),
+    )
+    .unwrap();
+  assert!(maybe_err.is_none());
+  assert_eq!(
+    maybe_res,
+    Some(load_fixture("code_action_response_refactor.json"))
+  );
+  let (maybe_res, maybe_err) = client
+    .write_request(
+      "codeAction/resolve",
+      load_fixture("code_action_resolve_params_refactor.json"),
+    )
+    .unwrap();
+  assert!(maybe_err.is_none());
+  assert_eq!(
+    maybe_res,
+    Some(load_fixture("code_action_resolve_response_refactor.json"))
+  );
+  shutdown(&mut client);
+}
+
+#[test]
+fn lsp_code_actions_refactor_no_disabled_support() {
+  let mut client = init("initialize_params_ca_no_disabled.json");
+  did_open(
+    &mut client,
+    json!({
+      "textDocument": {
+        "uri": "file:///a/file.ts",
+        "languageId": "typescript",
+        "version": 1,
+        "text": "interface A {\n  a: string;\n}\n\ninterface B {\n  b: string;\n}\n\nclass AB implements A, B {\n  a = \"a\";\n  b = \"b\";\n}\n\nnew AB().a;\n"
+      }
+    }),
+  );
+  let (maybe_res, maybe_err) = client
+    .write_request(
+      "textDocument/codeAction",
+      json!({
+        "textDocument": {
+          "uri": "file:///a/file.ts"
+        },
+        "range": {
+          "start": {
+            "line": 0,
+            "character": 0
+          },
+          "end": {
+            "line": 14,
+            "character": 0
+          }
+        },
+        "context": {
+          "diagnostics": [],
+          "only": [
+            "refactor"
+          ]
+        }
+      }),
+    )
+    .unwrap();
+  assert!(maybe_err.is_none());
+  assert_eq!(
+    maybe_res,
+    Some(load_fixture("code_action_response_no_disabled.json"))
+  );
+  shutdown(&mut client);
+}
+
 #[test]
 fn lsp_code_actions_deadlock() {
   let mut client = init("initialize_params.json");
@@ -2525,6 +2612,96 @@ fn lsp_auto_discover_registry() {
   shutdown(&mut client);
 }
 
+#[test]
+fn lsp_cache_location() {
+  let _g = http_server();
+  let temp_dir = TempDir::new().expect("could not create temp dir");
+  let mut params: lsp::InitializeParams =
+    serde_json::from_value(load_fixture("initialize_params.json")).unwrap();
+
+  params.root_uri = Some(Url::from_file_path(temp_dir.path()).unwrap());
+  if let Some(Value::Object(mut map)) = params.initialization_options {
+    map.insert("cache".to_string(), json!(".cache"));
+    params.initialization_options = Some(Value::Object(map));
+  }
+
+  let deno_exe = deno_exe_path();
+  let mut client = LspClient::new(&deno_exe).unwrap();
+  client
+    .write_request::<_, _, Value>("initialize", params)
+    .unwrap();
+
+  client.write_notification("initialized", json!({})).unwrap();
+  did_open(
+    &mut client,
+    json!({
+      "textDocument": {
+        "uri": "file:///a/file_01.ts",
+        "languageId": "typescript",
+        "version": 1,
+        "text": "export const a = \"a\";\n",
+      }
+    }),
+  );
+  let diagnostics = did_open(
+    &mut client,
+    load_fixture("did_open_params_import_hover.json"),
+  );
+  let diagnostics = diagnostics.into_iter().flat_map(|x| x.diagnostics);
+  assert_eq!(diagnostics.count(), 12);
+  let (maybe_res, maybe_err) = client
+    .write_request::<_, _, Value>(
+      "deno/cache",
+      json!({
+        "referrer": {
+          "uri": "file:///a/file.ts",
+        },
+        "uris": [],
+      }),
+    )
+    .unwrap();
+  assert!(maybe_err.is_none());
+  assert!(maybe_res.is_some());
+  let (maybe_res, maybe_err) = client
+    .write_request(
+      "textDocument/hover",
+      json!({
+        "textDocument": {
+          "uri": "file:///a/file.ts",
+        },
+        "position": {
+          "line": 0,
+          "character": 28
+        }
+      }),
+    )
+    .unwrap();
+  assert!(maybe_err.is_none());
+  assert_eq!(
+    maybe_res,
+    Some(json!({
+      "contents": {
+        "kind": "markdown",
+        "value": "**Resolved Dependency**\n\n**Code**: http&#8203;://127.0.0.1:4545/xTypeScriptTypes.js\n"
+      },
+      "range": {
+        "start": {
+          "line": 0,
+          "character": 20
+        },
+        "end":{
+          "line": 0,
+          "character": 61
+        }
+      }
+    }))
+  );
+  let cache_path = temp_dir.path().join(".cache");
+  assert!(cache_path.is_dir());
+  assert!(cache_path.join("gen").is_dir());
+  shutdown(&mut client);
+}
+
 #[test]
 fn lsp_diagnostics_warn() {
   let _g = http_server();
@@ -2536,7 +2713,7 @@ fn lsp_diagnostics_warn() {
         "uri": "file:///a/file.ts",
         "languageId": "typescript",
         "version": 1,
-        "text": "import * as a from \"http://127.0.0.1:4545/cli/tests/x_deno_warning.js\";\n\nconsole.log(a)\n",
+        "text": "import * as a from \"http://127.0.0.1:4545/x_deno_warning.js\";\n\nconsole.log(a)\n",
       },
     }),
   );
@@ -2549,7 +2726,7 @@ fn lsp_diagnostics_warn() {
         },
         "uris": [
           {
-            "uri": "http://127.0.0.1:4545/cli/tests/x_deno_warning.js",
+            "uri": "http://127.0.0.1:4545/x_deno_warning.js",
           }
         ],
       }),
@@ -2578,7 +2755,7 @@ fn lsp_diagnostics_warn() {
           },
           end: lsp::Position {
             line: 0,
-            character: 70
+            character: 60
           }
         },
         severity: Some(lsp::DiagnosticSeverity::Warning),
