@@ -49,12 +49,30 @@ itest!(fail {
   output: "test/fail.out",
 });
 
+itest!(load_unload {
+  args: "test test/load_unload.ts",
+  exit_code: 0,
+  output: "test/load_unload.out",
+});
+
 itest!(doc {
   args: "test --doc --allow-all test/doc.ts",
   exit_code: 1,
   output: "test/doc.out",
 });
 
+itest!(markdown {
+  args: "test --doc --allow-all test/markdown.md",
+  exit_code: 1,
+  output: "test/markdown.out",
+});
+
+itest!(text {
+  args: "test --doc --allow-all test/text.md",
+  exit_code: 0,
+  output: "test/text.out",
+});
+
 itest!(quiet {
   args: "test --quiet test/quiet.ts",
   exit_code: 0,
@@ -127,6 +145,12 @@ itest!(unhandled_rejection {
   output: "test/unhandled_rejection.out",
 });
 
+itest!(filter {
+  args: "test --filter=foo test/filter",
+  exit_code: 0,
+  output: "test/filter.out",
+});
+
 itest!(shuffle {
   args: "test --shuffle test/shuffle",
   exit_code: 0,
