@@ -200,7 +200,7 @@ unitTest({ perms: { net: true } }, async function httpServerInvalidMethod() {
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function httpServerWithTls(): Promise<void> {
+  async function httpServerWithTls() {
     const hostname = "localhost";
     const port = 4501;
 
@@ -208,8 +208,8 @@ unitTest(
       const listener = Deno.listenTls({
         hostname,
         port,
-        certFile: "cli/tests/tls/localhost.crt",
-        keyFile: "cli/tests/tls/localhost.key",
+        certFile: "cli/tests/testdata/tls/localhost.crt",
+        keyFile: "cli/tests/testdata/tls/localhost.key",
       });
       const conn = await listener.accept();
       const httpConn = Deno.serveHttp(conn);
@@ -226,7 +226,7 @@ unitTest(
       listener.close();
     })();
 
-    const caData = Deno.readTextFileSync("cli/tests/tls/RootCA.pem");
+    const caData = Deno.readTextFileSync("cli/tests/testdata/tls/RootCA.pem");
     const client = Deno.createHttpClient({ caData });
     const resp = await fetch(`https://${hostname}:${port}/`, {
       client,
@@ -641,12 +641,12 @@ unitTest({ perms: { net: true } }, async function httpServerWebSocket() {
       const { request, respondWith } = (await httpConn.nextRequest())!;
       const {
         response,
-        websocket,
+        socket,
       } = Deno.upgradeWebSocket(request);
-      websocket.onerror = () => fail();
-      websocket.onmessage = (m) => {
-        websocket.send(m.data);
-        websocket.close();
+      socket.onerror = () => fail();
+      socket.onmessage = (m) => {
+        socket.send(m.data);
+        socket.close(1001);
       };
       await respondWith(response);
       break;
@@ -731,3 +731,111 @@ unitTest({ perms: { net: true } }, async function httpCookieConcatenation() {
   assertEquals(text, "ok");
   await promise;
 });
+
+// https://github.com/denoland/deno/issues/11651
+unitTest({ perms: { net: true } }, async function httpServerPanic() {
+  const listener = Deno.listen({ port: 4501 });
+  const client = await Deno.connect({ port: 4501 });
+  const conn = await listener.accept();
+  const httpConn = Deno.serveHttp(conn);
+
+  // This message is incomplete on purpose, we'll forcefully close client connection
+  // after it's flushed to cause connection to error out on the server side.
+  const encoder = new TextEncoder();
+  await client.write(encoder.encode("GET / HTTP/1.1"));
+
+  httpConn.nextRequest();
+  await client.write(encoder.encode("\r\n\r\n"));
+  httpConn.close();
+
+  client.close();
+  listener.close();
+});
+
+// https://github.com/denoland/deno/issues/11595
+unitTest(
+  { perms: { net: true } },
+  async function httpServerIncompleteMessage() {
+    const listener = Deno.listen({ port: 4501 });
+    const def1 = deferred();
+    const def2 = deferred();
+
+    const client = await Deno.connect({ port: 4501 });
+    await client.write(new TextEncoder().encode(
+      `GET / HTTP/1.0\r\n\r\n`,
+    ));
+
+    const conn = await listener.accept();
+    const httpConn = Deno.serveHttp(conn);
+    const ev = await httpConn.nextRequest();
+    const { respondWith } = ev!;
+
+    const { readable, writable } = new TransformStream<Uint8Array>();
+    const writer = writable.getWriter();
+
+    async function writeResponse() {
+      await writer.write(
+        new TextEncoder().encode(
+          "written to the writable side of a TransformStream",
+        ),
+      );
+      await writer.close();
+    }
+
+    const errors: Error[] = [];
+
+    writeResponse()
+      .catch((error: Error) => {
+        errors.push(error);
+      })
+      .then(() => def1.resolve());
+
+    const res = new Response(readable);
+
+    respondWith(res)
+      .catch((error: Error) => errors.push(error))
+      .then(() => def2.resolve());
+
+    client.close();
+
+    await Promise.all([
+      def1,
+      def2,
+    ]);
+
+    listener.close();
+
+    assertEquals(errors.length, 2);
+    for (const error of errors) {
+      assertEquals(error.name, "Http");
+      assertEquals(
+        error.message,
+        "connection closed before message completed",
+      );
+    }
+  },
+);
+
+// https://github.com/denoland/deno/issues/11743
+unitTest(
+  { perms: { net: true } },
+  async function httpServerDoesntLeakResources() {
+    const listener = Deno.listen({ port: 4505 });
+    const [conn, clientConn] = await Promise.all([
+      listener.accept(),
+      Deno.connect({ port: 4505 }),
+    ]);
+    const httpConn = Deno.serveHttp(conn);
+
+    await Promise.all([
+      httpConn.nextRequest(),
+      clientConn.write(new TextEncoder().encode(
+        `GET / HTTP/1.1\r\nHost: 127.0.0.1:4505\r\n\r\n`,
+      )),
+    ]);
+
+    httpConn.close();
+    listener.close();
+    clientConn.close();
+  },
+);
