@@ -1,5 +1,26 @@
 import { assert, assertEquals, unitTest } from "./test_util.ts";
 
+// https://github.com/denoland/deno/issues/11664
+unitTest(async function testImportArrayBufferKey() {
+  const subtle = window.crypto.subtle;
+  assert(subtle);
+
+  // deno-fmt-ignore
+  const key = new Uint8Array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16]);
+
+  const cryptoKey = await subtle.importKey(
+    "raw",
+    key.buffer,
+    { name: "HMAC", hash: "SHA-1" },
+    true,
+    ["sign"],
+  );
+  assert(cryptoKey);
+
+  // Test key usage
+  await subtle.sign({ name: "HMAC" }, cryptoKey, new Uint8Array(8));
+});
+
 // TODO(@littledivy): Remove this when we enable WPT for sign_verify
 unitTest(async function testSignVerify() {
   const subtle = window.crypto.subtle;
@@ -138,3 +159,37 @@ unitTest(async function testSignRSASSAKey() {
 
   assert(signature);
 });
+
+unitTest(async function subtleCryptoHmacImportExport() {
+  // deno-fmt-ignore
+  const rawKey = new Uint8Array([
+    1, 2, 3, 4, 5, 6, 7, 8,
+    9, 10, 11, 12, 13, 14, 15, 16
+  ]);
+  const key = await crypto.subtle.importKey(
+    "raw",
+    rawKey,
+    { name: "HMAC", hash: "SHA-256" },
+    true,
+    ["sign"],
+  );
+  const actual = await crypto.subtle.sign(
+    { name: "HMAC" },
+    key,
+    new Uint8Array([1, 2, 3, 4]),
+  );
+  // deno-fmt-ignore
+  const expected = new Uint8Array([
+    59, 170, 255, 216, 51, 141, 51, 194,
+    213, 48, 41, 191, 184, 40, 216, 47,
+    130, 165, 203, 26, 163, 43, 38, 71,
+    23, 122, 222, 1, 146, 46, 182, 87,
+  ]);
+  assertEquals(
+    new Uint8Array(actual),
+    expected,
+  );
+
+  const exportedKey = await crypto.subtle.exportKey("raw", key);
+  assertEquals(new Uint8Array(exportedKey), rawKey);
+});
