@@ -81,7 +81,7 @@ pub async fn lint_files(
           sort_diagnostics(&mut file_diagnostics);
           for d in file_diagnostics.iter() {
             has_error.store(true, Ordering::Relaxed);
-            reporter.visit_diagnostic(&d, source.split('\n').collect());
+            reporter.visit_diagnostic(d, source.split('\n').collect());
           }
         }
         Err(err) => {
@@ -127,6 +127,8 @@ pub fn print_rules_list(json: bool) {
     println!("Available rules:");
     for rule in lint_rules {
       println!(" - {}", rule.code());
+      println!("   help: https://lint.deno.land/#{}", rule.code());
+      println!();
     }
   }
 }
@@ -135,9 +137,6 @@ pub fn create_linter(syntax: Syntax, rules: Vec<Box<dyn LintRule>>) -> Linter {
   LinterBuilder::default()
     .ignore_file_directive("deno-lint-ignore-file")
     .ignore_diagnostic_directive("deno-lint-ignore")
-    .lint_unused_ignore_directives(true)
-    // TODO(bartlomieju): switch to true
-    .lint_unknown_rules(false)
     .syntax(syntax)
     .rules(rules)
     .build()
@@ -230,10 +229,10 @@ impl LintReporter for PrettyLintReporter {
   fn visit_diagnostic(&mut self, d: &LintDiagnostic, source_lines: Vec<&str>) {
     self.lint_count += 1;
 
-    let pretty_message =
-      format!("({}) {}", colors::gray(&d.code), d.message.clone());
+    let pretty_message = format!("({}) {}", colors::red(&d.code), &d.message);
 
     let message = format_diagnostic(
+      &d.code,
       &pretty_message,
       &source_lines,
       d.range.clone(),
@@ -269,6 +268,7 @@ impl LintReporter for PrettyLintReporter {
 }
 
 pub fn format_diagnostic(
+  diagnostic_code: &str,
   message_line: &str,
   source_lines: &[&str],
   range: deno_lint::diagnostic::Range,
@@ -301,23 +301,25 @@ pub fn format_diagnostic(
     }
   }
 
-  if let Some(hint) = maybe_hint {
-    format!(
-      "{}\n{}\n    at {}\n\n    {} {}",
-      message_line,
-      lines.join("\n"),
-      formatted_location,
-      colors::gray("hint:"),
-      hint,
-    )
+  let hint = if let Some(hint) = maybe_hint {
+    format!("    {} {}\n", colors::cyan("hint:"), hint)
   } else {
-    format!(
-      "{}\n{}\n    at {}",
-      message_line,
-      lines.join("\n"),
-      formatted_location
-    )
-  }
+    "".to_string()
+  };
+  let help = format!(
+    "    {} for further information visit https://lint.deno.land/#{}",
+    colors::cyan("help:"),
+    diagnostic_code
+  );
+
+  format!(
+    "{message_line}\n{snippets}\n    at {formatted_location}\n\n{hint}{help}",
+    message_line = message_line,
+    snippets = lines.join("\n"),
+    formatted_location = formatted_location,
+    hint = hint,
+    help = help
+  )
 }
 
 #[derive(Serialize)]
