@@ -231,7 +231,7 @@ impl Validator for EditorHelper {
     let mut stack: Vec<Token> = Vec::new();
     let mut in_template = false;
 
-    for item in ast::lex("", ctx.input(), &MediaType::TypeScript) {
+    for item in ast::lex(ctx.input(), &MediaType::TypeScript) {
       if let TokenOrComment::Token(token) = item.inner {
         match token {
           Token::BackQuote => in_template = !in_template,
@@ -290,9 +290,13 @@ impl Highlighter for EditorHelper {
   fn highlight_candidate<'c>(
     &self,
     candidate: &'c str,
-    _completion: rustyline::CompletionType,
+    completion: rustyline::CompletionType,
   ) -> Cow<'c, str> {
-    self.highlight(candidate, 0)
+    if completion == CompletionType::List {
+      candidate.into()
+    } else {
+      self.highlight(candidate, 0)
+    }
   }
 
   fn highlight_char(&self, line: &str, _: usize) -> bool {
@@ -302,7 +306,7 @@ impl Highlighter for EditorHelper {
   fn highlight<'l>(&self, line: &'l str, _: usize) -> Cow<'l, str> {
     let mut out_line = String::from(line);
 
-    for item in ast::lex("", line, &MediaType::TypeScript) {
+    for item in ast::lex(line, &MediaType::TypeScript) {
       // Adding color adds more bytes to the string,
       // so an offset is needed to stop spans falling out of sync.
       let offset = out_line.len() - line.len();
@@ -418,6 +422,20 @@ Object.defineProperty(globalThis, "_error", {
 });
 "#;
 
+enum EvaluationOutput {
+  Value(String),
+  Error(String),
+}
+
+impl std::fmt::Display for EvaluationOutput {
+  fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+    match self {
+      EvaluationOutput::Value(value) => f.write_str(value),
+      EvaluationOutput::Error(value) => f.write_str(value),
+    }
+  }
+}
+
 struct ReplSession {
   worker: MainWorker,
   session: LocalInspectorSession,
@@ -497,7 +515,7 @@ impl ReplSession {
   pub async fn evaluate_line_and_get_output(
     &mut self,
     line: &str,
-  ) -> Result<String, AnyError> {
+  ) -> Result<EvaluationOutput, AnyError> {
     match self.evaluate_line_with_object_wrapping(line).await {
       Ok(evaluate_response) => {
         let evaluate_result = evaluate_response.get("result").unwrap();
@@ -512,20 +530,20 @@ impl ReplSession {
 
         let value = self.get_eval_value(evaluate_result).await?;
         Ok(match evaluate_exception_details {
-          Some(_) => format!("Uncaught {}", value),
-          None => value,
+          Some(_) => EvaluationOutput::Error(format!("Uncaught {}", value)),
+          None => EvaluationOutput::Value(value),
         })
       }
       Err(err) => {
         // handle a parsing diagnostic
         match err.downcast_ref::<Diagnostic>() {
-          Some(diagnostic) => Ok(format!(
+          Some(diagnostic) => Ok(EvaluationOutput::Error(format!(
             "{}: {} at {}:{}",
             colors::red("parse error"),
             diagnostic.message,
             diagnostic.location.line,
             diagnostic.location.col
-          )),
+          ))),
           None => Err(err),
         }
       }
@@ -555,7 +573,7 @@ impl ReplSession {
       if evaluate_response.get("exceptionDetails").is_some()
         && wrapped_line != line
       {
-        self.evaluate_ts_expression(&line).await?
+        self.evaluate_ts_expression(line).await?
       } else {
         evaluate_response
       };
@@ -632,7 +650,7 @@ impl ReplSession {
     expression: &str,
   ) -> Result<Value, AnyError> {
     let parsed_module =
-      crate::ast::parse("repl.ts", &expression, &crate::MediaType::TypeScript)?;
+      crate::ast::parse("repl.ts", expression, &crate::MediaType::TypeScript)?;
 
     let transpiled_src = parsed_module
       .transpile(&crate::ast::EmitOptions {
@@ -707,6 +725,7 @@ async fn read_line_and_poll(
 pub async fn run(
   program_state: &ProgramState,
   worker: MainWorker,
+  maybe_eval: Option<String>,
 ) -> Result<(), AnyError> {
   let mut repl_session = ReplSession::initialize(worker).await?;
   let (message_tx, mut message_rx) = channel(1);
@@ -721,6 +740,14 @@ pub async fn run(
   let history_file_path = program_state.dir.root.join("deno_history.txt");
   let editor = ReplEditor::new(helper, history_file_path);
 
+  if let Some(eval) = maybe_eval {
+    let output = repl_session.evaluate_line_and_get_output(&eval).await?;
+    // only output errors
+    if let EvaluationOutput::Error(error_text) = output {
+      println!("error in --eval flag. {}", error_text);
+    }
+  }
+
   println!("Deno {}", crate::version::deno());
   println!("exit using ctrl+d or close()");
 
