@@ -75,6 +75,9 @@ delete Object.prototype.__proto__;
   /** @type {Map<string, ts.SourceFile>} */
   const sourceFileCache = new Map();
 
+  /** @type {string[]=} */
+  let scriptFileNamesCache;
+
   /** @type {Map<string, string>} */
   const scriptVersionCache = new Map();
 
@@ -148,7 +151,7 @@ delete Object.prototype.__proto__;
     // TS1103: 'for-await-of' statement is only allowed within an async function
     // or async generator.
     1103,
-    // TS2306: File 'file:///Users/rld/src/deno/cli/tests/subdir/amd_like.js' is
+    // TS2306: File 'file:///Users/rld/src/deno/cli/tests/testdata/subdir/amd_like.js' is
     // not a module.
     2306,
     // TS2688: Cannot find type definition file for '...'.
@@ -163,7 +166,7 @@ delete Object.prototype.__proto__;
     // TS5009: Cannot find the common subdirectory path for the input files.
     5009,
     // TS5055: Cannot write file
-    // 'http://localhost:4545/cli/tests/subdir/mt_application_x_javascript.j4.js'
+    // 'http://localhost:4545/subdir/mt_application_x_javascript.j4.js'
     // because it would overwrite input file.
     5055,
     // TypeScript is overly opinionated that only CommonJS modules kinds can
@@ -370,7 +373,12 @@ delete Object.prototype.__proto__;
     },
     getScriptFileNames() {
       debug("host.getScriptFileNames()");
-      return core.opSync("op_script_names", undefined);
+      // tsc requests the script file names multiple times even though it can't
+      // possibly have changed, so we will memoize it on a per request basis.
+      if (scriptFileNamesCache) {
+        return scriptFileNamesCache;
+      }
+      return scriptFileNamesCache = core.opSync("op_script_names", undefined);
     },
     getScriptVersion(specifier) {
       debug(`host.getScriptVersion("${specifier}")`);
@@ -378,9 +386,8 @@ delete Object.prototype.__proto__;
       if (sourceFile) {
         return sourceFile.version ?? "1";
       }
-      // tsc neurotically requests the script version multiple times even though
-      // it can't possibly have changed, so we will memoize it on a per request
-      // basis.
+      // tsc requests the script version multiple times even though it can't
+      // possibly have changed, so we will memoize it on a per request basis.
       if (scriptVersionCache.has(specifier)) {
         return scriptVersionCache.get(specifier);
       }
@@ -543,6 +550,8 @@ delete Object.prototype.__proto__;
    */
   function serverRequest({ id, ...request }) {
     debug(`serverRequest()`, { id, ...request });
+    // reset all memoized source files names
+    scriptFileNamesCache = undefined;
     // evict all memoized source file versions
     scriptVersionCache.clear();
     switch (request.method) {
@@ -575,6 +584,44 @@ delete Object.prototype.__proto__;
         );
         return respond(id, sourceFile && sourceFile.text);
       }
+      case "getApplicableRefactors": {
+        return respond(
+          id,
+          languageService.getApplicableRefactors(
+            request.specifier,
+            request.range,
+            {
+              quotePreference: "double",
+              allowTextChangesInNewFiles: true,
+              provideRefactorNotApplicableReason: true,
+            },
+            undefined,
+            request.kind,
+          ),
+        );
+      }
+      case "getEditsForRefactor": {
+        return respond(
+          id,
+          languageService.getEditsForRefactor(
+            request.specifier,
+            {
+              indentSize: 2,
+              indentStyle: ts.IndentStyle.Smart,
+              semicolons: ts.SemicolonPreference.Insert,
+              convertTabsToSpaces: true,
+              insertSpaceBeforeAndAfterBinaryOperators: true,
+              insertSpaceAfterCommaDelimiter: true,
+            },
+            request.range,
+            request.refactorName,
+            request.actionName,
+            {
+              quotePreference: "double",
+            },
+          ),
+        );
+      }
       case "getCodeFixes": {
         return respond(
           id,
